package
Version:
v0.0.0-...-d64eb31
Opens a new window with list of versions in this module.
Published: Jan 7, 2025
License: MIT
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Config interface {
GetGRPCPort() int
GetGRPCAuthServerAddress() string
}
type GINComponent interface {
GetPort() int
GetRouter() *gin.Engine
}
type GormComponent interface {
GetDB() *gorm.DB
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.