pb

package
v0.0.0-...-d64eb31 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 7, 2025 License: MIT Imports: 8 Imported by: 0

Documentation

Index

Constants

const (
	UserService_CreateUser_FullMethodName    = "/pb.UserService/CreateUser"
	UserService_GetUserRole_FullMethodName   = "/pb.UserService/GetUserRole"
	UserService_GetUserById_FullMethodName   = "/pb.UserService/GetUserById"
	UserService_GetUsersByIds_FullMethodName = "/pb.UserService/GetUsersByIds"
)
const (
	AuthService_IntrospectToken_FullMethodName = "/pb.AuthService/IntrospectToken"
)
const (
	HlsService_NewHlsStream_FullMethodName = "/pb.HlsService/NewHlsStream"
)
const (
	StreamService_FindStreamById_FullMethodName = "/pb.StreamService/FindStreamById"
)

Variables

var AuthService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "pb.AuthService",
	HandlerType: (*AuthServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "IntrospectToken",
			Handler:    _AuthService_IntrospectToken_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "auth.proto",
}

AuthService_ServiceDesc is the grpc.ServiceDesc for AuthService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var File_image_proto protoreflect.FileDescriptor
var File_stream_proto protoreflect.FileDescriptor
var HlsService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "pb.HlsService",
	HandlerType: (*HlsServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "NewHlsStream",
			Handler:    _HlsService_NewHlsStream_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "hls.proto",
}

HlsService_ServiceDesc is the grpc.ServiceDesc for HlsService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var StreamService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "pb.StreamService",
	HandlerType: (*StreamServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "FindStreamById",
			Handler:    _StreamService_FindStreamById_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "stream.proto",
}

StreamService_ServiceDesc is the grpc.ServiceDesc for StreamService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var UserService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "pb.UserService",
	HandlerType: (*UserServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "CreateUser",
			Handler:    _UserService_CreateUser_Handler,
		},
		{
			MethodName: "GetUserRole",
			Handler:    _UserService_GetUserRole_Handler,
		},
		{
			MethodName: "GetUserById",
			Handler:    _UserService_GetUserById_Handler,
		},
		{
			MethodName: "GetUsersByIds",
			Handler:    _UserService_GetUsersByIds_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "user.proto",
}

UserService_ServiceDesc is the grpc.ServiceDesc for UserService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

Functions

func RegisterAuthServiceServer

func RegisterAuthServiceServer(s grpc.ServiceRegistrar, srv AuthServiceServer)

func RegisterHlsServiceServer

func RegisterHlsServiceServer(s grpc.ServiceRegistrar, srv HlsServiceServer)

func RegisterStreamServiceServer

func RegisterStreamServiceServer(s grpc.ServiceRegistrar, srv StreamServiceServer)

func RegisterUserServiceServer

func RegisterUserServiceServer(s grpc.ServiceRegistrar, srv UserServiceServer)

Types

type AuthServiceClient

type AuthServiceClient interface {
	IntrospectToken(ctx context.Context, in *IntrospectReq, opts ...grpc.CallOption) (*IntrospectResp, error)
}

AuthServiceClient is the client API for AuthService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type AuthServiceServer

type AuthServiceServer interface {
	IntrospectToken(context.Context, *IntrospectReq) (*IntrospectResp, error)
}

AuthServiceServer is the server API for AuthService service. All implementations should embed UnimplementedAuthServiceServer for forward compatibility.

type CreateUserReq

type CreateUserReq struct {
	FirstName string `protobuf:"bytes,1,opt,name=first_name,json=firstName,proto3" json:"first_name,omitempty"`
	LastName  string `protobuf:"bytes,2,opt,name=last_name,json=lastName,proto3" json:"last_name,omitempty"`
	Email     string `protobuf:"bytes,3,opt,name=email,proto3" json:"email,omitempty"`
	// contains filtered or unexported fields
}

func (*CreateUserReq) Descriptor deprecated

func (*CreateUserReq) Descriptor() ([]byte, []int)

Deprecated: Use CreateUserReq.ProtoReflect.Descriptor instead.

func (*CreateUserReq) GetEmail

func (x *CreateUserReq) GetEmail() string

func (*CreateUserReq) GetFirstName

func (x *CreateUserReq) GetFirstName() string

func (*CreateUserReq) GetLastName

func (x *CreateUserReq) GetLastName() string

func (*CreateUserReq) ProtoMessage

func (*CreateUserReq) ProtoMessage()

func (*CreateUserReq) ProtoReflect

func (x *CreateUserReq) ProtoReflect() protoreflect.Message

func (*CreateUserReq) Reset

func (x *CreateUserReq) Reset()

func (*CreateUserReq) String

func (x *CreateUserReq) String() string

type FindStreamReq

type FindStreamReq struct {
	Id int32 `protobuf:"varint,1,opt,name=id,proto3" json:"id,omitempty"`
	// contains filtered or unexported fields
}

func (*FindStreamReq) Descriptor deprecated

func (*FindStreamReq) Descriptor() ([]byte, []int)

Deprecated: Use FindStreamReq.ProtoReflect.Descriptor instead.

func (*FindStreamReq) GetId

func (x *FindStreamReq) GetId() int32

func (*FindStreamReq) ProtoMessage

func (*FindStreamReq) ProtoMessage()

func (*FindStreamReq) ProtoReflect

func (x *FindStreamReq) ProtoReflect() protoreflect.Message

func (*FindStreamReq) Reset

func (x *FindStreamReq) Reset()

func (*FindStreamReq) String

func (x *FindStreamReq) String() string

type FindStreamResp

type FindStreamResp struct {
	Title     string `protobuf:"bytes,1,opt,name=title,proto3" json:"title,omitempty"`
	State     string `protobuf:"bytes,2,opt,name=state,proto3" json:"state,omitempty"`
	Status    int32  `protobuf:"varint,3,opt,name=status,proto3" json:"status,omitempty"`
	ChannelId int32  `protobuf:"varint,4,opt,name=channel_id,json=channelId,proto3" json:"channel_id,omitempty"`
	// contains filtered or unexported fields
}

func (*FindStreamResp) Descriptor deprecated

func (*FindStreamResp) Descriptor() ([]byte, []int)

Deprecated: Use FindStreamResp.ProtoReflect.Descriptor instead.

func (*FindStreamResp) GetChannelId

func (x *FindStreamResp) GetChannelId() int32

func (*FindStreamResp) GetState

func (x *FindStreamResp) GetState() string

func (*FindStreamResp) GetStatus

func (x *FindStreamResp) GetStatus() int32

func (*FindStreamResp) GetTitle

func (x *FindStreamResp) GetTitle() string

func (*FindStreamResp) ProtoMessage

func (*FindStreamResp) ProtoMessage()

func (*FindStreamResp) ProtoReflect

func (x *FindStreamResp) ProtoReflect() protoreflect.Message

func (*FindStreamResp) Reset

func (x *FindStreamResp) Reset()

func (*FindStreamResp) String

func (x *FindStreamResp) String() string

type GetUserByIdReq

type GetUserByIdReq struct {
	Id int32 `protobuf:"varint,1,opt,name=id,proto3" json:"id,omitempty"`
	// contains filtered or unexported fields
}

func (*GetUserByIdReq) Descriptor deprecated

func (*GetUserByIdReq) Descriptor() ([]byte, []int)

Deprecated: Use GetUserByIdReq.ProtoReflect.Descriptor instead.

func (*GetUserByIdReq) GetId

func (x *GetUserByIdReq) GetId() int32

func (*GetUserByIdReq) ProtoMessage

func (*GetUserByIdReq) ProtoMessage()

func (*GetUserByIdReq) ProtoReflect

func (x *GetUserByIdReq) ProtoReflect() protoreflect.Message

func (*GetUserByIdReq) Reset

func (x *GetUserByIdReq) Reset()

func (*GetUserByIdReq) String

func (x *GetUserByIdReq) String() string

type GetUserRoleReps

type GetUserRoleReps struct {
	Role string `protobuf:"bytes,1,opt,name=role,proto3" json:"role,omitempty"`
	// contains filtered or unexported fields
}

func (*GetUserRoleReps) Descriptor deprecated

func (*GetUserRoleReps) Descriptor() ([]byte, []int)

Deprecated: Use GetUserRoleReps.ProtoReflect.Descriptor instead.

func (*GetUserRoleReps) GetRole

func (x *GetUserRoleReps) GetRole() string

func (*GetUserRoleReps) ProtoMessage

func (*GetUserRoleReps) ProtoMessage()

func (*GetUserRoleReps) ProtoReflect

func (x *GetUserRoleReps) ProtoReflect() protoreflect.Message

func (*GetUserRoleReps) Reset

func (x *GetUserRoleReps) Reset()

func (*GetUserRoleReps) String

func (x *GetUserRoleReps) String() string

type GetUserRoleReq

type GetUserRoleReq struct {
	Id int32 `protobuf:"varint,1,opt,name=id,proto3" json:"id,omitempty"`
	// contains filtered or unexported fields
}

func (*GetUserRoleReq) Descriptor deprecated

func (*GetUserRoleReq) Descriptor() ([]byte, []int)

Deprecated: Use GetUserRoleReq.ProtoReflect.Descriptor instead.

func (*GetUserRoleReq) GetId

func (x *GetUserRoleReq) GetId() int32

func (*GetUserRoleReq) ProtoMessage

func (*GetUserRoleReq) ProtoMessage()

func (*GetUserRoleReq) ProtoReflect

func (x *GetUserRoleReq) ProtoReflect() protoreflect.Message

func (*GetUserRoleReq) Reset

func (x *GetUserRoleReq) Reset()

func (*GetUserRoleReq) String

func (x *GetUserRoleReq) String() string

type GetUsersByIdsReq

type GetUsersByIdsReq struct {
	Ids []int32 `protobuf:"varint,1,rep,packed,name=ids,proto3" json:"ids,omitempty"`
	// contains filtered or unexported fields
}

func (*GetUsersByIdsReq) Descriptor deprecated

func (*GetUsersByIdsReq) Descriptor() ([]byte, []int)

Deprecated: Use GetUsersByIdsReq.ProtoReflect.Descriptor instead.

func (*GetUsersByIdsReq) GetIds

func (x *GetUsersByIdsReq) GetIds() []int32

func (*GetUsersByIdsReq) ProtoMessage

func (*GetUsersByIdsReq) ProtoMessage()

func (*GetUsersByIdsReq) ProtoReflect

func (x *GetUsersByIdsReq) ProtoReflect() protoreflect.Message

func (*GetUsersByIdsReq) Reset

func (x *GetUsersByIdsReq) Reset()

func (*GetUsersByIdsReq) String

func (x *GetUsersByIdsReq) String() string

type HlsServiceClient

type HlsServiceClient interface {
	NewHlsStream(ctx context.Context, in *NewHlsStreamReq, opts ...grpc.CallOption) (*NewHlsStreamResp, error)
}

HlsServiceClient is the client API for HlsService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

func NewHlsServiceClient

func NewHlsServiceClient(cc grpc.ClientConnInterface) HlsServiceClient

type HlsServiceServer

type HlsServiceServer interface {
	NewHlsStream(context.Context, *NewHlsStreamReq) (*NewHlsStreamResp, error)
}

HlsServiceServer is the server API for HlsService service. All implementations should embed UnimplementedHlsServiceServer for forward compatibility.

type Image

type Image struct {
	Id        int64  `protobuf:"varint,1,opt,name=id,proto3" json:"id,omitempty"`
	Url       string `protobuf:"bytes,2,opt,name=url,proto3" json:"url,omitempty"`
	Width     int32  `protobuf:"varint,3,opt,name=width,proto3" json:"width,omitempty"`
	Height    int32  `protobuf:"varint,4,opt,name=height,proto3" json:"height,omitempty"`
	CloudName string `protobuf:"bytes,6,opt,name=cloud_name,json=cloudName,proto3" json:"cloud_name,omitempty"`
	Extension string `protobuf:"bytes,7,opt,name=extension,proto3" json:"extension,omitempty"`
	// contains filtered or unexported fields
}

func (*Image) Descriptor deprecated

func (*Image) Descriptor() ([]byte, []int)

Deprecated: Use Image.ProtoReflect.Descriptor instead.

func (*Image) GetCloudName

func (x *Image) GetCloudName() string

func (*Image) GetExtension

func (x *Image) GetExtension() string

func (*Image) GetHeight

func (x *Image) GetHeight() int32

func (*Image) GetId

func (x *Image) GetId() int64

func (*Image) GetUrl

func (x *Image) GetUrl() string

func (*Image) GetWidth

func (x *Image) GetWidth() int32

func (*Image) ProtoMessage

func (*Image) ProtoMessage()

func (*Image) ProtoReflect

func (x *Image) ProtoReflect() protoreflect.Message

func (*Image) Reset

func (x *Image) Reset()

func (*Image) String

func (x *Image) String() string

type IntrospectReq

type IntrospectReq struct {
	AccessToken string `protobuf:"bytes,1,opt,name=access_token,json=accessToken,proto3" json:"access_token,omitempty"`
	// contains filtered or unexported fields
}

func (*IntrospectReq) Descriptor deprecated

func (*IntrospectReq) Descriptor() ([]byte, []int)

Deprecated: Use IntrospectReq.ProtoReflect.Descriptor instead.

func (*IntrospectReq) GetAccessToken

func (x *IntrospectReq) GetAccessToken() string

func (*IntrospectReq) ProtoMessage

func (*IntrospectReq) ProtoMessage()

func (*IntrospectReq) ProtoReflect

func (x *IntrospectReq) ProtoReflect() protoreflect.Message

func (*IntrospectReq) Reset

func (x *IntrospectReq) Reset()

func (*IntrospectReq) String

func (x *IntrospectReq) String() string

type IntrospectResp

type IntrospectResp struct {
	Tid string `protobuf:"bytes,1,opt,name=tid,proto3" json:"tid,omitempty"`
	Sub string `protobuf:"bytes,2,opt,name=sub,proto3" json:"sub,omitempty"`
	// contains filtered or unexported fields
}

func (*IntrospectResp) Descriptor deprecated

func (*IntrospectResp) Descriptor() ([]byte, []int)

Deprecated: Use IntrospectResp.ProtoReflect.Descriptor instead.

func (*IntrospectResp) GetSub

func (x *IntrospectResp) GetSub() string

func (*IntrospectResp) GetTid

func (x *IntrospectResp) GetTid() string

func (*IntrospectResp) ProtoMessage

func (*IntrospectResp) ProtoMessage()

func (*IntrospectResp) ProtoReflect

func (x *IntrospectResp) ProtoReflect() protoreflect.Message

func (*IntrospectResp) Reset

func (x *IntrospectResp) Reset()

func (*IntrospectResp) String

func (x *IntrospectResp) String() string

type NewHlsStreamReq

type NewHlsStreamReq struct {
	StreamId   string `protobuf:"bytes,1,opt,name=stream_id,json=streamId,proto3" json:"stream_id,omitempty"`
	StreamKey  string `protobuf:"bytes,2,opt,name=stream_key,json=streamKey,proto3" json:"stream_key,omitempty"`
	ServerUrl  string `protobuf:"bytes,3,opt,name=server_url,json=serverUrl,proto3" json:"server_url,omitempty"`
	Resolution int32  `protobuf:"varint,4,opt,name=resolution,proto3" json:"resolution,omitempty"`
	Fps        int32  `protobuf:"varint,5,opt,name=fps,proto3" json:"fps,omitempty"`
	// contains filtered or unexported fields
}

func (*NewHlsStreamReq) Descriptor deprecated

func (*NewHlsStreamReq) Descriptor() ([]byte, []int)

Deprecated: Use NewHlsStreamReq.ProtoReflect.Descriptor instead.

func (*NewHlsStreamReq) GetFps

func (x *NewHlsStreamReq) GetFps() int32

func (*NewHlsStreamReq) GetResolution

func (x *NewHlsStreamReq) GetResolution() int32

func (*NewHlsStreamReq) GetServerUrl

func (x *NewHlsStreamReq) GetServerUrl() string

func (*NewHlsStreamReq) GetStreamId

func (x *NewHlsStreamReq) GetStreamId() string

func (*NewHlsStreamReq) GetStreamKey

func (x *NewHlsStreamReq) GetStreamKey() string

func (*NewHlsStreamReq) ProtoMessage

func (*NewHlsStreamReq) ProtoMessage()

func (*NewHlsStreamReq) ProtoReflect

func (x *NewHlsStreamReq) ProtoReflect() protoreflect.Message

func (*NewHlsStreamReq) Reset

func (x *NewHlsStreamReq) Reset()

func (*NewHlsStreamReq) String

func (x *NewHlsStreamReq) String() string

type NewHlsStreamResp

type NewHlsStreamResp struct {
	// contains filtered or unexported fields
}

func (*NewHlsStreamResp) Descriptor deprecated

func (*NewHlsStreamResp) Descriptor() ([]byte, []int)

Deprecated: Use NewHlsStreamResp.ProtoReflect.Descriptor instead.

func (*NewHlsStreamResp) ProtoMessage

func (*NewHlsStreamResp) ProtoMessage()

func (*NewHlsStreamResp) ProtoReflect

func (x *NewHlsStreamResp) ProtoReflect() protoreflect.Message

func (*NewHlsStreamResp) Reset

func (x *NewHlsStreamResp) Reset()

func (*NewHlsStreamResp) String

func (x *NewHlsStreamResp) String() string

type NewUserIdResp

type NewUserIdResp struct {
	Id int32 `protobuf:"varint,1,opt,name=id,proto3" json:"id,omitempty"`
	// contains filtered or unexported fields
}

func (*NewUserIdResp) Descriptor deprecated

func (*NewUserIdResp) Descriptor() ([]byte, []int)

Deprecated: Use NewUserIdResp.ProtoReflect.Descriptor instead.

func (*NewUserIdResp) GetId

func (x *NewUserIdResp) GetId() int32

func (*NewUserIdResp) ProtoMessage

func (*NewUserIdResp) ProtoMessage()

func (*NewUserIdResp) ProtoReflect

func (x *NewUserIdResp) ProtoReflect() protoreflect.Message

func (*NewUserIdResp) Reset

func (x *NewUserIdResp) Reset()

func (*NewUserIdResp) String

func (x *NewUserIdResp) String() string

type PublicUserInfo

type PublicUserInfo struct {
	Id          int32  `protobuf:"varint,1,opt,name=id,proto3" json:"id,omitempty"`
	FirstName   string `protobuf:"bytes,2,opt,name=first_name,json=firstName,proto3" json:"first_name,omitempty"`
	LastName    string `protobuf:"bytes,3,opt,name=last_name,json=lastName,proto3" json:"last_name,omitempty"`
	UserName    string `protobuf:"bytes,4,opt,name=user_name,json=userName,proto3" json:"user_name,omitempty"`
	DisplayName string `protobuf:"bytes,5,opt,name=display_name,json=displayName,proto3" json:"display_name,omitempty"`
	SystemRole  string `protobuf:"bytes,6,opt,name=system_role,json=systemRole,proto3" json:"system_role,omitempty"`
	Avatar      *Image `protobuf:"bytes,7,opt,name=avatar,proto3" json:"avatar,omitempty"`
	// contains filtered or unexported fields
}

func (*PublicUserInfo) Descriptor deprecated

func (*PublicUserInfo) Descriptor() ([]byte, []int)

Deprecated: Use PublicUserInfo.ProtoReflect.Descriptor instead.

func (*PublicUserInfo) GetAvatar

func (x *PublicUserInfo) GetAvatar() *Image

func (*PublicUserInfo) GetDisplayName

func (x *PublicUserInfo) GetDisplayName() string

func (*PublicUserInfo) GetFirstName

func (x *PublicUserInfo) GetFirstName() string

func (*PublicUserInfo) GetId

func (x *PublicUserInfo) GetId() int32

func (*PublicUserInfo) GetLastName

func (x *PublicUserInfo) GetLastName() string

func (*PublicUserInfo) GetSystemRole

func (x *PublicUserInfo) GetSystemRole() string

func (*PublicUserInfo) GetUserName

func (x *PublicUserInfo) GetUserName() string

func (*PublicUserInfo) ProtoMessage

func (*PublicUserInfo) ProtoMessage()

func (*PublicUserInfo) ProtoReflect

func (x *PublicUserInfo) ProtoReflect() protoreflect.Message

func (*PublicUserInfo) Reset

func (x *PublicUserInfo) Reset()

func (*PublicUserInfo) String

func (x *PublicUserInfo) String() string

type PublicUserInfoResp

type PublicUserInfoResp struct {
	User *PublicUserInfo `protobuf:"bytes,1,opt,name=user,proto3" json:"user,omitempty"`
	// contains filtered or unexported fields
}

func (*PublicUserInfoResp) Descriptor deprecated

func (*PublicUserInfoResp) Descriptor() ([]byte, []int)

Deprecated: Use PublicUserInfoResp.ProtoReflect.Descriptor instead.

func (*PublicUserInfoResp) GetUser

func (x *PublicUserInfoResp) GetUser() *PublicUserInfo

func (*PublicUserInfoResp) ProtoMessage

func (*PublicUserInfoResp) ProtoMessage()

func (*PublicUserInfoResp) ProtoReflect

func (x *PublicUserInfoResp) ProtoReflect() protoreflect.Message

func (*PublicUserInfoResp) Reset

func (x *PublicUserInfoResp) Reset()

func (*PublicUserInfoResp) String

func (x *PublicUserInfoResp) String() string

type PublicUsersInfoResp

type PublicUsersInfoResp struct {
	Users []*PublicUserInfo `protobuf:"bytes,1,rep,name=users,proto3" json:"users,omitempty"`
	// contains filtered or unexported fields
}

func (*PublicUsersInfoResp) Descriptor deprecated

func (*PublicUsersInfoResp) Descriptor() ([]byte, []int)

Deprecated: Use PublicUsersInfoResp.ProtoReflect.Descriptor instead.

func (*PublicUsersInfoResp) GetUsers

func (x *PublicUsersInfoResp) GetUsers() []*PublicUserInfo

func (*PublicUsersInfoResp) ProtoMessage

func (*PublicUsersInfoResp) ProtoMessage()

func (*PublicUsersInfoResp) ProtoReflect

func (x *PublicUsersInfoResp) ProtoReflect() protoreflect.Message

func (*PublicUsersInfoResp) Reset

func (x *PublicUsersInfoResp) Reset()

func (*PublicUsersInfoResp) String

func (x *PublicUsersInfoResp) String() string

type StreamServiceClient

type StreamServiceClient interface {
	FindStreamById(ctx context.Context, in *FindStreamReq, opts ...grpc.CallOption) (*FindStreamResp, error)
}

StreamServiceClient is the client API for StreamService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type StreamServiceServer

type StreamServiceServer interface {
	FindStreamById(context.Context, *FindStreamReq) (*FindStreamResp, error)
}

StreamServiceServer is the server API for StreamService service. All implementations should embed UnimplementedStreamServiceServer for forward compatibility.

type UnimplementedAuthServiceServer

type UnimplementedAuthServiceServer struct{}

UnimplementedAuthServiceServer should be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedAuthServiceServer) IntrospectToken

type UnimplementedHlsServiceServer

type UnimplementedHlsServiceServer struct{}

UnimplementedHlsServiceServer should be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedHlsServiceServer) NewHlsStream

type UnimplementedStreamServiceServer

type UnimplementedStreamServiceServer struct{}

UnimplementedStreamServiceServer should be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedStreamServiceServer) FindStreamById

type UnimplementedUserServiceServer

type UnimplementedUserServiceServer struct{}

UnimplementedUserServiceServer should be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedUserServiceServer) CreateUser

func (UnimplementedUserServiceServer) GetUserById

func (UnimplementedUserServiceServer) GetUserRole

func (UnimplementedUserServiceServer) GetUsersByIds

type UnsafeAuthServiceServer

type UnsafeAuthServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeAuthServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to AuthServiceServer will result in compilation errors.

type UnsafeHlsServiceServer

type UnsafeHlsServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeHlsServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to HlsServiceServer will result in compilation errors.

type UnsafeStreamServiceServer

type UnsafeStreamServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeStreamServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to StreamServiceServer will result in compilation errors.

type UnsafeUserServiceServer

type UnsafeUserServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeUserServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to UserServiceServer will result in compilation errors.

type UserServiceClient

type UserServiceClient interface {
	CreateUser(ctx context.Context, in *CreateUserReq, opts ...grpc.CallOption) (*NewUserIdResp, error)
	GetUserRole(ctx context.Context, in *GetUserRoleReq, opts ...grpc.CallOption) (*GetUserRoleReps, error)
	GetUserById(ctx context.Context, in *GetUserByIdReq, opts ...grpc.CallOption) (*PublicUserInfoResp, error)
	GetUsersByIds(ctx context.Context, in *GetUsersByIdsReq, opts ...grpc.CallOption) (*PublicUsersInfoResp, error)
}

UserServiceClient is the client API for UserService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type UserServiceServer

type UserServiceServer interface {
	CreateUser(context.Context, *CreateUserReq) (*NewUserIdResp, error)
	GetUserRole(context.Context, *GetUserRoleReq) (*GetUserRoleReps, error)
	GetUserById(context.Context, *GetUserByIdReq) (*PublicUserInfoResp, error)
	GetUsersByIds(context.Context, *GetUsersByIdsReq) (*PublicUsersInfoResp, error)
}

UserServiceServer is the server API for UserService service. All implementations should embed UnimplementedUserServiceServer for forward compatibility.

Jump to