package
Version:
v0.0.0-...-d64eb31
Opens a new window with list of versions in this module.
Published: Jan 7, 2025
License: MIT
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Message struct {
Id string `json:"id"`
Channel string `json:"channel"`
Data any `json:"data"`
CreatedAt time.Time `json:"created_at"`
}
func NewMessage(data interface{}) *Message
Source Files
¶
Directories
¶
Click to show internal directories.
Click to hide internal directories.